package betterquesting.api2.client.gui.panels.content;

import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.resources.textures.ColorTexture;
import betterquesting.api2.client.gui.resources.textures.IGuiTexture;
import betterquesting.api2.client.gui.resources.textures.ItemTexture;
import betterquesting.api2.client.gui.resources.textures.LayeredTexture;
import betterquesting.api2.client.gui.resources.textures.OreDictTexture;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.client.Minecraft;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.item.ItemStack;

/* loaded from: betterquesting_api2_client_gui_panels_content.jar:betterquesting/api2/client/gui/panels/content/PanelItemSlot.class */
public class PanelItemSlot extends PanelButtonStorage<BigItemStack> {
    private final boolean showCount;
    private final boolean oreDict;
    private final List<BigItemStack> oreVariants;

    public PanelItemSlot(IGuiRect rect, int id, BigItemStack value) {
        this(rect, id, value, false, false);
    }

    public PanelItemSlot(IGuiRect rect, int id, BigItemStack value, boolean showCount) {
        this(rect, id, value, showCount, false);
    }

    public PanelItemSlot(IGuiRect rect, int id, BigItemStack value, boolean showCount, boolean oreDict) {
        super(rect, id, "", value);
        this.oreVariants = new ArrayList();
        this.showCount = showCount;
        this.oreDict = oreDict;
        setTextures(PresetTexture.ITEM_FRAME.getTexture(), PresetTexture.ITEM_FRAME.getTexture(), new LayeredTexture(new IGuiTexture[]{PresetTexture.ITEM_FRAME.getTexture(), new ColorTexture(PresetColor.ITEM_HIGHLIGHT.getColor(), new GuiPadding(1, 1, 1, 1))}));
        setStoredValue(value);
    }

    public PanelItemSlot setStoredValue(BigItemStack value) {
        super.setStoredValue(value);
        if (value != null) {
            Minecraft mc = Minecraft.func_71410_x();
            setIcon((this.oreDict || value.getBaseStack().func_77960_j() == 32767) ? new OreDictTexture(1.0f, value, this.showCount, true) : new ItemTexture(value, this.showCount, true), 1);
            setTooltip(value.getBaseStack().func_82840_a(mc.field_71439_g, mc.field_71474_y.field_82882_x));
        } else {
            setIcon(null);
            setTooltip(null);
        }
        updateOreStacks();
        return this;
    }

    public List<String> getTooltip(int mx, int my) {
        BigItemStack ttStack = (BigItemStack) getStoredValue();
        if (ttStack == null || !getTransform().contains(mx, my)) {
            return null;
        }
        if (this.oreDict && this.oreVariants.size() > 0) {
            ttStack = this.oreVariants.get(((int) (System.currentTimeMillis() / 1000.0d)) % this.oreVariants.size());
        }
        if (ttStack != null) {
            Minecraft mc = Minecraft.func_71410_x();
            return ttStack.getBaseStack().func_82840_a(mc.field_71439_g, mc.field_71474_y.field_82882_x);
        }
        return null;
    }

    private void updateOreStacks() {
        if (this.oreVariants == null) {
            return;
        }
        this.oreVariants.clear();
        BigItemStack stack = (BigItemStack) getStoredValue();
        if (stack == null) {
            return;
        }
        if (!stack.hasOreDict()) {
            if (stack.getBaseStack().func_77960_j() == 32767) {
                List<ItemStack> subItems = new ArrayList<>();
                stack.getBaseStack().func_77973_b().func_150895_a(stack.getBaseStack().func_77973_b(), CreativeTabs.field_78027_g, subItems);
                for (ItemStack sStack : subItems) {
                    BigItemStack bStack = new BigItemStack(sStack);
                    bStack.stackSize = stack.stackSize;
                    this.oreVariants.add(bStack);
                }
                return;
            }
            this.oreVariants.add(stack);
            return;
        }
        for (ItemStack iStack : stack.getOreIngredient().getMatchingStacks()) {
            if (iStack.func_77960_j() == 32767) {
                List<ItemStack> subItems2 = new ArrayList<>();
                iStack.func_77973_b().func_150895_a(iStack.func_77973_b(), CreativeTabs.field_78027_g, subItems2);
                for (ItemStack sStack2 : subItems2) {
                    BigItemStack bStack2 = new BigItemStack(sStack2);
                    bStack2.stackSize = stack.stackSize;
                    this.oreVariants.add(bStack2);
                }
            } else {
                BigItemStack bStack3 = new BigItemStack(iStack);
                bStack3.stackSize = stack.stackSize;
                this.oreVariants.add(bStack3);
            }
        }
    }
}
